@@ -30,7 +30,6 @@
 #include <gdk/gdkx.h>
 #include <libgnome/gnome-program.h>
 #include <libgnomeui/gnome-ui-init.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <libgnomeui/gnome-client.h>
 #include <dbus/dbus-glib-bindings.h>
 #include <string.h>
@@ -355,10 +354,12 @@ main (int argc, char **argv)
 	}
 
 	/* Commandline parsing is done here */
-	context = g_option_context_new (_(" GNOME Help Browser"));
+	context = g_option_context_new (N_(" GNOME Help Browser"));
 
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
+	g_option_context_set_translation_domain(context, GETTEXT_PACKAGE);
+
 	gtk_window_set_auto_startup_notification(FALSE);
 
 	program = gnome_program_init (PACKAGE, VERSION,
@@ -376,8 +377,6 @@ main (int argc, char **argv)
 	g_set_application_name (_("Help"));
 	gtk_window_set_default_icon_name ("gnome-help");
 
-	gnome_vfs_init ();
-
 	if (!private) {
 		connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
 		if (!connection) {
@@ -387,7 +386,8 @@ main (int argc, char **argv)
 	}
 
 	if (!yelp_html_initialize ()) {
-		g_error ("Could not initialize gecko!");
+		g_printerr ("Could not initialize gecko!\n");
+		exit (1);
 	}
 
 	if (files != NULL && files[0] != NULL) {
